function [] = MWM_proc_data(habadd)
%
% Simple program for analysing the rat performance data.
%
% The mat file "MWMperf.mat" is required for this, since it contains all
% the data to be processed. Place it in the same folder as this function.
%
% This program has 2 modes: Acquisition and Probe analysis. You can select
% which option to choose when running this program.
%
% The first input arguement specifies whether you want to display habituation
% data (acquisition analysis only), as well as the format of statistics.
%
% examples:
%
% MWM_proc_data(0) - Displays habituation data in addition to acquisition
%
% MWM_proc_data(1) - Displays only acquisition data
%
% MWM_proc_data(2) - Displays only acquisition data, and includes a 2-way
%                    ANOVA (effects of test session and group)
%
%
% There's some more options that may be set (e.g. font size for plotting).
% Have a look at the top of this file for details.
%
% If the axis legend gets in the way, simply click on it and move it.
% 
% Richard Pinnell
% May 2017



%%%%%%%%%%% EXTRA OPTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%
% The target quadrant we're looking at (for e.g. time spent in quadrant X).
% The platform is located in the NW quadrant (quad = 3).
% 1 = NE, 2 = SE, 3 = NW (platform), 4 = SW
quad = 3;       

% font and marker size for plotting
fsize = 12;
msize = 13;

% Set this variable from 1-4, for analysing only a particular trial
% (acquisition analysis only). Default is 0, in which all trials (for a
% particular session) are averaged.
trialno = 0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
if ~exist('habadd','var')    
  habadd =0;
end

load('MWMperf.mat');

fprintf('\nSelect Test Period');
fprintf('\n1........Acquisition');
fprintf('\n2........Probe');
analperiod = input('\n..... ');

grouplist = {'SHAMvar','TBSvar','XBEFvar'};
plotchar = '*h';
plotarray = ['ko';'r^';'bs'];
 
switch quad
    case 1
        tag = 'NE';        
    case 2
        tag = 'SE';
    case 3
        tag = 'NW';
    case 4
        tag = 'SW';
end

testday = {};
testgroup = {};
bigarray = [];

fprintf('\nSelect Analysis Type');
fprintf('\n1........Platform Latency');
fprintf('\n2........Annulus Latency');
fprintf('\n3........Annulus Crossings');
fprintf('\n4........Path Length');
fprintf('\n5........Average Speed (with resting)');
fprintf('\n6........Average Speed (without resting)');
fprintf('\n7........Wall Time');
fprintf('\n8........Wishaw Error');
fprintf('\n9........Average Distance to Target');
fprintf('\n10........Mean Directionality');
fprintf('\n11........Resting Time');
fprintf('\n12........Time in Quadrant');
fprintf('\n13........Distance in Quadrants');
fprintf('\n14........Time in Zone');
analtype = input('\n..... ');

if (analperiod==1)
    
    SHAMvar = [];
    TBSvar = [];    
    XBEFvar = [];
    
    for r = 1:length(RatGroups),
        rat = RatGroups{r,1};
        group = RatGroups{r,2};        
        
        switch analtype
            case 1
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.LatencyPlat;']);
                ptitle = 'Latency to Platform';
                ytext = 'Platform Latency (sec)';
            case 2
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.LatencyAnn;']);
                ptitle = 'Latency to Annulus';
                ytext = 'Time (sec)';
            case 3
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.AnnCrossings;']);
                ptitle = 'Number of Annulus Crossings';
                ytext = 'Time (sec)';
            case 4
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.PathLength;']);
                ptitle = 'Path Length';
                ytext = 'Path Length (cm)';
            case 5
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.SpeedWiStop;']);
                ptitle = 'Average Speed (with stopping)';
                ytext = 'Speed';
            case 6
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.SpeedNoStop;']);
                ptitle = 'Average Speed (without Stopping)';
                ytext = 'Speed';
            case 7
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.WallTime;']);
                ptitle = 'Wall Time';
                ytext = 'Time at Wall (%)';
            case 8
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.WishErr;']);
                ptitle = 'Wishaw Index';
                ytext = 'Wishaw Index (%)';
            case 9
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.DistTarget;']);
                ptitle = 'Distance to Target';
                ytext = 'Avg. Distance to Target (cm)';
            case 10
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.MDirect;']);
                ptitle = 'Mean Directionality';
                ytext = 'Mean Directionality';
            case 11
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.RestTime;']);
                ptitle = 'Resting Time';
                ytext = 'Resting Time (?)';
            case 12
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.QuadTime;']);
                ptitle = ['Quadrant Time ' tag];
                ytext = 'Time in Target Quadrant (%)';
            case 13
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.QuadDist;']);
                ptitle = ['Quadrant Distance ' tag];
                ytext = 'Distance in Target Quadrant (%)';
            case 14
                eval(['Rat = RatPerformance.Rat' num2str(rat) '.ZTime;']);
                ptitle = 'Zone Time';
                ytext = 'Time in Target Zone (%)';
        end
        
        value = [];
        if (habadd == 0)
            eval(['acqval = Rat.H0;']);
            value = [value grabval(acqval,2)];
        end
            for k=1:8,
                eval(['acqval = Rat.A' num2str(k) ';']);
                value = [value grabval(acqval,quad)];                                
            end            
                        
            if (group(1)=='S')
                SHAMvar = [SHAMvar; value];
            elseif (group(1)=='T')
                TBSvar = [TBSvar; value];
            elseif (group(1)=='X')
                XBEFvar = [XBEFvar; value];
            end
    end
    
    f1 = figure;hold on;       
    for rep=1:length(grouplist),
        eval(['errorbar(mean(' grouplist{rep} ',1),ste(' grouplist{rep} ',1),''' plotarray(rep,1) ''',''LineWidth'',2);']);
    end
    for rep=1:length(grouplist),
        eval(['plot(mean(' grouplist{rep} ',1),''' plotarray(rep,1) '-' plotarray(rep,2) ''',''MarkerEdgeColor'',''k'',''MarkerFaceColor'',''' plotarray(rep,1) ''',''MarkerSize'',' num2str(msize) ');']);
    end
    ylabel([ytext],'fontsize',fsize,'fontname','Times New Roman');
    xlabel('Session No.','fontsize',fsize,'fontname','Times New Roman');
    abc = axis;
    abc(1) = 0.5;
    for rep=1:length(grouplist),
        eval(['errorbar(mean(' grouplist{rep} ',1),ste(' grouplist{rep} ',1),''' plotarray(rep,1) ''');']);
    end
    for rep=1:length(grouplist),
        eval(['plot(mean(' grouplist{rep} ',1),''' plotarray(rep,1) '-' plotarray(rep,2) ''',''LineWidth'',2,''MarkerEdgeColor'',''k'',''MarkerFaceColor'',''' plotarray(rep,1) ''',''MarkerSize'',' num2str(msize) ');']);
    end
    set(gca,'fontname','Times New Roman');
    set(gca,'FontSize',fsize,'linewidth',1.5)
    if (habadd==0)
        abc(2) = 9.5;
        set(gca,'XTickLabel',{'H','1','2','3','4','5','6','7','8'})
    else
        abc(2) = 8.5;
    end
    abc(3) = 0;
    axis(abc);  
    
    if (habadd==2)
        bigarray = [];
        testday = {};
        testgroup = {};
        
        
        for j=1:8,
            for m=1:length(grouplist),
                eval(['currentvar = ' grouplist{m} ';']);
                for k=1:size(currentvar,1)
                    bigarray = [bigarray; currentvar(k,j)];
                    testgroup = [testgroup; grouplist{m}];
                    testday = [testday; num2str(j)];
                end
            end
        end
        [h,p]=anovan(bigarray,{testday, testgroup},'full')
    end               
        eval(['def = size(' grouplist{1} ',2);'])
        
        % Code for putting significance stars on the plot
        sigarray = [];
        sigarray = zeros(length(grouplist)-1,def);
        qlen = length(grouplist)-1;
        for q=1:qlen,
            for j=1:def,
                eval(['[h,p]=ttest2(' grouplist{1} '(:,j),' grouplist{q+1} '(:,j));']);
                if (p<0.00001)
                    sigarray(q,j)=4;
                elseif (p<0.0001)
                    sigarray(q,j)=3;
                elseif (p<0.001)
                    sigarray(q,j)=2;
                elseif (p<0.05)
                    sigarray(q,j)=1;
                end
            end
        end
                
        meanarray = [];
        stearray = [];
        for m=1:length(grouplist),
            eval(['meanarray = [meanarray; mean(' grouplist{m} ',1)];']);
            eval(['stearray = [stearray; ste(' grouplist{m} ',1)];']);
        end        
        siglevel = [max(meanarray)+max(stearray)+(max(stearray/2));min(meanarray)-min(stearray)-(min(stearray/2))];
        abc = axis;
        astep = (abc(4)-abc(3))/30;
        hstep = 0.2;
        for m=1:length(grouplist)-1,
            abc = sigarray(m,:);
            eval(['comp1 = mean(' grouplist{1} ',1);']);
            eval(['comp2 = mean(' grouplist{m+1} ',1);']);
            asign = (abc&ones(1,def)).*((comp1>comp2)+1);
            for q=1:length(abc)
                for r=1:sigarray(m,q)
                    if (asign(q)==1)
                        eval(['plot(q+((r-1)*hstep)-((sigarray(m,q)-1)*(hstep/2)),siglevel(asign(q),q)+(2*(m*astep)),''' plotarray(1,1) plotchar(m) ' '',''Markersize'',13);']);
                    elseif (asign(q)==2)
                        eval(['plot(q+((r-1)*hstep)-((sigarray(m,q)-1)*(hstep/2)),siglevel(asign(q),q)-(2*(m*astep)),''' plotarray(1,1) plotchar(m) ' '',''Markersize'',13);']);
                    end
                end
            end
        end    
        
    legend('SHAM','DUR','BEF');
        
        
else
    fprintf('\nSelect Probe Session');
    fprintf('\n1........First');
    fprintf('\n2........Second');
    prnum = input('\n..... ');
        
    SHAMvar = [];
    TBSvar = [];    
    XBEFvar = [];
    
    for r = 1:length(RatGroups),
        rat = RatGroups{r,1};
        group = RatGroups{r,2};
            
            switch analtype
                case 1
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.LatencyPlat;']);
                    ptitle = 'Latency to Platform';
                    ytext = 'Latency to Platform (sec)';
                case 2
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.LatencyAnn;']);
                    ptitle = 'Latency to Annulus';
                    ytext = 'Latency to Annulus (sec)';
                case 3
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.AnnCrossings;']);
                    ptitle = 'Number of Annulus Crossings';
                    ytext = 'No of Annulus Crossings';
                case 4
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.PathLength;']);
                    ptitle = 'Path Length';
                    ytext = 'Path Length (cm)';
                case 5
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.SpeedWiStop;']);
                    ptitle = 'Average Speed (with stopping)';
                    ytext = 'Average Speed (with rest)';
                case 6
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.SpeedNoStop;']);
                    ptitle = 'Average Speed (without Stopping)';
                    ytext = 'Average Speed (without rest)';
                case 7
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.WallTime;']);
                    ptitle = 'Wall Time';
                    ytext = 'Time spent at Wall (%)';
                case 8
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.WishErr;']);
                    ptitle = 'Wishaw Index';
                    ytext = 'Wishaw Index (%)';
                case 9
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.DistTarget;']);
                    ptitle = 'Distance to Target';
                    ytext = 'Avg. Distance to Target (cm)';
                case 10
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.MDirect;']);
                    ptitle = 'Mean Directionality';
                    ytext = 'Mean Directionality';
                case 11
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.RestTime;']);
                    ptitle = 'Resting Time';
                    ytext = 'Average Resting Time (sec)';
                case 12
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.QuadTime;']);
                    ptitle = ['Quadrant Time ' tag];
                    ytext = 'Time Spent in Target Quadrant (%)';
                case 13
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.QuadDist;']);
                    ptitle = ['Quadrant Distance ' tag];
                    ytext = 'Distance Travelled in Target Quadrant (%)';
                case 14
                    eval(['Rat = RatPerformance.Rat' num2str(rat) '.ZTime;']);
                    ptitle = 'Zone Time';
                    ytext = 'Time Spent in Target Zone (%)';
            end
                                   
            if (~isfield(Rat, ['P' num2str(prnum)]))
                continue
            end            
            
            eval(['acqval = Rat.P' num2str(prnum) ';']);
            value = grabval(acqval,quad);
            
            if (group(1)=='S')
                SHAMvar = [SHAMvar; value];        
            elseif (group(1)=='T')
                TBSvar = [TBSvar; value];
            elseif (group(1)=='X')
                XBEFvar = [XBEFvar; value];
            end
            testgroup = [testgroup; group(1)];        
    end
    
    figure;hold on;
    plotmean = [];plotste = [];
    for rep=1:length(grouplist),
        eval(['plotmean = [plotmean; mean(' grouplist{rep} ',1)];']);
        eval(['plotste = [plotste; ste(' grouplist{rep} ',1)];']);
    end
    errorbar(plotmean,plotste,'.');
    bar(plotmean');
    title(['Probe Session ' num2str(prnum)]);
     set(gca,'XTickLabel',{[]})
     set(gca,'XTickLabel',{[],'SHAM',[],'DUR',[],'BEF'})
    ylabel([ytext]);
    
    if (habadd == 2)
        bigarray = [];
        testgroup = {};
        for m=1:length(grouplist),
            eval(['currentvar = ' grouplist{m} ';']);
            for k=1:size(currentvar)
                bigarray = [bigarray; currentvar(k)];
                testgroup = [testgroup; grouplist{m}];
            end
        end
        [h,p]=anovan(bigarray,{testgroup},'full')
    end
end
